@@ -35,6 +35,8 @@ mod impl_;
 #[cfg(not(feature = "phf-map"))]
 #[path = "impl_bin_search.rs"]
 mod impl_;
+#[cfg(test)]
+mod tests;
 
 /// A "guess" of the MIME/Media Type(s) of an extension or path as one or more
 /// [`Mime`](struct.Mime.html) instances.
@@ -64,7 +66,7 @@ impl MimeGuess {
 			return Self(&[]);
 		}
 
-		impl_::get_mime_types(ext).map_or(Self(&[]), |v| Self(v))
+		impl_::get_mime_types(ext).map_or(Self(&[]), Self)
 	}
 
 	/// Guess the MIME type of `path` by its extension (as defined by
@@ -143,7 +145,8 @@ impl MimeGuess {
 	/// See [Note: Ordering](#note-ordering) above.
 	pub fn first_or_else<F>(&self, default_fn: F) -> Mime
 	where
-		F: FnOnce() -> Mime, {
+		F: FnOnce() -> Mime,
+	{
 		self.first().unwrap_or_else(default_fn)
 	}
 
@@ -289,97 +292,3 @@ pub fn get_mime_extensions_str(mut mime_str: &str) -> Option<&'static [&'static
 pub fn get_extensions(toplevel: &str, sublevel: &str) -> Option<&'static [&'static str]> {
 	impl_::get_extensions(toplevel, sublevel)
 }
-
-#[cfg(test)]
-mod tests {
-	include!("mime_types.rs");
-
-	use super::{expect_mime, from_ext, from_path, get_mime_extensions_str};
-	use std::fmt::Debug;
-	use std::path::Path;
-
-	#[test]
-	fn check_type_bounds() {
-		fn assert_type_bounds<T: Clone + Debug + Send + Sync + 'static>() {}
-
-		assert_type_bounds::<super::MimeGuess>();
-		assert_type_bounds::<super::Iter>();
-		assert_type_bounds::<super::IterRaw>();
-	}
-
-	#[test]
-	fn test_mime_type_guessing() {
-		assert_eq!(
-			from_ext("gif").first_or_octet_stream().to_string(),
-			"image/gif".to_string()
-		);
-		assert_eq!(
-			from_ext("TXT").first_or_octet_stream().to_string(),
-			"text/plain".to_string()
-		);
-		assert_eq!(
-			from_ext("blahblah").first_or_octet_stream().to_string(),
-			"application/octet-stream".to_string()
-		);
-
-		assert_eq!(
-			from_path(Path::new("/path/to/file.gif"))
-				.first_or_octet_stream()
-				.to_string(),
-			"image/gif".to_string()
-		);
-		assert_eq!(
-			from_path("/path/to/file.gif").first_or_octet_stream().to_string(),
-			"image/gif".to_string()
-		);
-	}
-
-	#[test]
-	fn test_mime_type_guessing_opt() {
-		assert_eq!(from_ext("gif").first().unwrap().to_string(), "image/gif".to_string());
-		assert_eq!(from_ext("TXT").first().unwrap().to_string(), "text/plain".to_string());
-		assert_eq!(from_ext("blahblah").first(), None);
-
-		assert_eq!(
-			from_path("/path/to/file.gif").first().unwrap().to_string(),
-			"image/gif".to_string()
-		);
-		assert_eq!(from_path("/path/to/file").first(), None);
-	}
-
-	#[test]
-	fn test_are_mime_types_parseable() {
-		for (_, mimes) in MIME_TYPES {
-			mimes.iter().for_each(|s| {
-				expect_mime(s);
-			});
-		}
-	}
-
-	// RFC: Is this test necessary anymore? --@cybergeek94, 2/1/2016
-	#[test]
-	fn test_are_extensions_ascii() {
-		for (ext, _) in MIME_TYPES {
-			assert!(ext.is_ascii(), "Extension not ASCII: {:?}", ext);
-		}
-	}
-
-	#[test]
-	fn test_are_extensions_sorted() {
-		// simultaneously checks the requirement that duplicate extension entries are adjacent
-		for (&(ext, _), &(n_ext, _)) in MIME_TYPES.iter().zip(MIME_TYPES.iter().skip(1)) {
-			assert!(
-				ext <= n_ext,
-				"Extensions in src/mime_types should be sorted lexicographically
-                in ascending order. Failed assert: {:?} <= {:?}",
-				ext,
-				n_ext
-			);
-		}
-	}
-
-	#[test]
-	fn test_get_mime_extensions_str_no_panic_if_bad_mime() {
-		assert_eq!(get_mime_extensions_str(""), None);
-	}
-}
