@@ -39,7 +39,7 @@ pub static MIME_TYPES: &[(&str, &[&str])] = &[
 	("aas", &["application/x-authorware-seg"]),
 	("aax", &["audio/vnd.audible.aax"]),
 	("abw", &["application/x-abiword"]),
-	("ac", &["application/pkix-attr-cert", "application/vnd.nokia.n-gage.ac+xml"]),
+	("ac", &["application/vnd.nokia.n-gage.ac+xml", "application/pkix-attr-cert"]),
 	("ac3", &["audio/ac3"]),
 	("aca", &["application/octet-stream"]),
 	("acc", &["application/vnd.americandynamics.acc"]),
@@ -106,7 +106,6 @@ pub static MIME_TYPES: &[(&str, &[&str])] = &[
 	("au", &["audio/basic"]),
 	("avi", &["video/x-msvideo"]),
 	("avif", &["image/avif"]),
-	("avif", &["image/avif-sequence"]),
 	("aw", &["application/applixware"]),
 	("axa", &["audio/annodex"]),
 	("axs", &["application/olescript"]),
@@ -186,7 +185,6 @@ pub static MIME_TYPES: &[(&str, &[&str])] = &[
 	("chrt", &["application/vnd.kde.kchart"]),
 	("cif", &["chemical/x-cif"]),
 	("cii", &["application/vnd.anser-web-certificate-issue-initiation"]),
-	("cii", &["application/vnd.anser-web-certificate-issue-initiation"]),
 	("cil", &["application/vnd.ms-artgalry"]),
 	("cjs", &["application/node"]),
 	("cla", &["application/vnd.claymore"]),
@@ -294,7 +292,6 @@ pub static MIME_TYPES: &[(&str, &[&str])] = &[
 	("dtd", &["application/xml-dtd"]),
 	("dts", &["audio/vnd.dts"]),
 	("dtsconfig", &["text/xml"]),
-	("dtshd", &["audio/vnd.dts"]),
 	("dtshd", &["audio/vnd.dts.hd"]),
 	("dump", &["application/octet-stream"]),
 	("dv", &["video/x-dv"]),
@@ -551,7 +548,7 @@ pub static MIME_TYPES: &[(&str, &[&str])] = &[
 	("java", &["text/x-java-source", "application/octet-stream"]),
 	("jck", &["application/liquidmotion"]),
 	("jcz", &["application/liquidmotion"]),
-	("jfif", &["image/pjpeg"]),
+	("jfif", &["image/jpeg"]),
 	("jisp", &["application/vnd.jisp"]),
 	("jls", &["image/jls"]),
 	("jlt", &["application/vnd.hp-jlyt"]),
@@ -1251,7 +1248,6 @@ pub static MIME_TYPES: &[(&str, &[&str])] = &[
 	("uris", &["text/uri-list"]),
 	("urls", &["text/uri-list"]),
 	("usdz", &["model/vnd.usdz+zip"]),
-	("usdz", &["model/vnd.usdz+zip"]),
 	("user", &["text/plain"]),
 	("ustar", &["application/x-ustar"]),
 	("utz", &["application/vnd.uiq.theme"]),
